@@ -36,8 +36,8 @@
 /**
  * Version of Biborb
  */
-$biborb_version = "1.3";
-$date_release = "29 May 2004";
+$biborb_version = "1.3.1";
+$date_release = "26 June 2004";
 
 
 /**
