@@ -24,3 +24,14 @@ function toggle_element(id)
     }
 }
 
+function addGroup()
+{
+	var groups = document.fields._groups;
+	var groupslist = document.fields.groupslist;
+	if(groups.value != ""){
+		groups.value += ',';
+	}
+	groups.value += groupslist.options[groupslist.selectedIndex].value;
+	
+
+}
